@@ -8,7 +8,7 @@
 
 package Mail::Message::Body::Multipart;
 use vars '$VERSION';
-$VERSION = '3.014';
+$VERSION = '3.015';
 
 use base 'Mail::Message::Body';
 
@@ -109,7 +109,10 @@ sub nrLines()
     }
 
     if(my $epilogue = $self->epilogue)
-    {   $nr += $epilogue->nrLines;
+    {   # nrLines should match mbox counts, which is a bit
+        # unclear w.r.t. the \n after a multipart separator
+        # line.
+        $nr += $epilogue->nrLines -1;
     }
 
     $nr;
